#[repr(transparent)]pub struct MediaWorkerId(usize);Expand description
runtime-local identifier for one rtc media worker
this is worker identity, not a worker count or vector capacity
convert to raw usize only when indexing worker storage or projecting
telemetry and diagnostics fields
Tuple Fields
0: usizeImplementations